@@ -669,9 +669,9 @@ void MidiDecode::setMidiBankOrRootDir(uint bank_or_root_num, bool in_place, bool
     if (in_place)
     {
         if (!setRootDir)
-            synth->setRootBank(UNUSED, bank_or_root_num, false);
+            synth->setRootBank(UNUSED, bank_or_root_num, true);
         else
-            synth->setRootBank(bank_or_root_num, UNUSED, false);
+            synth->setRootBank(bank_or_root_num, UNUSED, true);
         return;
     }
 
@@ -706,9 +706,18 @@ void MidiDecode::setMidiProgram(uchar ch, int prg, bool in_place)
     memset(&putData, 0xff, sizeof(putData));
     putData.data.value = prg;
     putData.data.type = TOPLEVEL::type::Write | TOPLEVEL::type::Integer;
-    putData.data.source = TOPLEVEL::action::toAll;
-    putData.data.control = MIDI::control::instrument;
-    putData.data.part = TOPLEVEL::section::midiIn;
+    if (in_place)
+    {
+        putData.data.source = TOPLEVEL::action::lowPrio;
+        putData.data.control = MAIN::control::refreshInstrumentUI;
+        putData.data.part = TOPLEVEL::section::main;
+    }
+    else
+    {
+        putData.data.source = TOPLEVEL::action::toAll;
+        putData.data.control = MIDI::control::instrument;
+        putData.data.part = TOPLEVEL::section::midiIn;
+    }
     //putData.data.parameter = 0xc0;
 
     /*
@@ -729,7 +738,8 @@ void MidiDecode::setMidiProgram(uchar ch, int prg, bool in_place)
                 if (in_place)
                 {
                     synth->partonoffLock(npart, -1);
-                    synth->setProgramFromBank(putData, false);
+                    synth->setProgramFromBank(putData, true);
+                    synth->interchange.decodeLoopback.write(putData.bytes);
                 }
                 else
                 {
@@ -745,7 +755,8 @@ void MidiDecode::setMidiProgram(uchar ch, int prg, bool in_place)
         if (in_place)
         {
             synth->partonoffLock(ch, -1);
-            synth->setProgramFromBank(putData, false);
+            synth->setProgramFromBank(putData, true);
+            synth->interchange.decodeLoopback.write(putData.bytes);
         }
         else
             synth->midilearn.writeMidi(putData, false);
