@@ -7,7 +7,7 @@
     Copyright 2017-2018, Will Godfrey
 
     This file is part of yoshimi, which is free software: you can redistribute
-    it and/or modify it under the terms of the GNU Library General Public
+    it and/or modify it under the terms of the GNU General Public
     License as published by the Free Software Foundation; either version 2 of
     the License, or (at your option) any later version.
 
@@ -28,12 +28,15 @@
 #include <cmath>
 #include <iostream>
 
-using namespace std;
-
 #include "Misc/XMLwrapper.h"
 #include "Misc/SynthEngine.h"
+#include "Misc/SynthHelper.h"
 #include "Params/Controller.h"
 
+using func::power;
+using func::powFrac;
+
+
 Controller::Controller(SynthEngine *_synth):
     synth(_synth)
 {
@@ -42,7 +45,7 @@ Controller::Controller(SynthEngine *_synth):
 }
 
 
-void Controller::defaults(void)
+void Controller::defaults()
 {
     setpitchwheelbendrange(200); // 2 halftones
     expression.receive = 1;
@@ -123,13 +126,13 @@ void Controller::setpitchwheel(int value)
     pitchwheel.data = value;
     float cents = value / 8192.0f;
     cents *= pitchwheel.bendrange;
-    pitchwheel.relfreq = powf(2.0f, cents / 1200.0f);
+    pitchwheel.relfreq = power<2>(cents / 1200.0f);
     // original comment
     //fprintf(stderr,"%ld %ld -> %.3f\n",pitchwheel.bendrange,pitchwheel.data,pitchwheel.relfreq);fflush(stderr);
 }
 
 
-void Controller::setpitchwheelbendrange(unsigned short int value)
+void Controller::setpitchwheelbendrange(ushort value)
 {
     pitchwheel.bendrange = value;
 }
@@ -156,7 +159,7 @@ void Controller::setfiltercutoff(int value)
 void Controller::setfilterq(int value)
 {
     filterq.data = value;
-    filterq.relq = powf(30.0f, (value - 64.0f) / 64.0f * (filterq.depth / 64.0f));
+    filterq.relq = power<30>((value - 64.0f) / 64.0f * (filterq.depth / 64.0f));
 }
 
 
@@ -165,7 +168,7 @@ void Controller::setbandwidth(int value)
     bandwidth.data = value;
     if (!bandwidth.exponential)
     {
-        float tmp = powf(25.0f, powf(bandwidth.depth / 127.0f, 1.5f)) - 1.0f;
+        float tmp = power<25>(powf(bandwidth.depth / 127.0f, 1.5f)) - 1.0f;
         if (value < 64 && bandwidth.depth >= 64)
             tmp = 1.0f;
         bandwidth.relbw = (value / 64.0f - 1.0f) * tmp + 1.0f;
@@ -174,7 +177,7 @@ void Controller::setbandwidth(int value)
     }
     else
     {
-        bandwidth.relbw = powf(25.0f, (value - 64.0f) / 64.0f * (bandwidth.depth / 64.0f));
+        bandwidth.relbw = power<25>((value - 64.0f) / 64.0f * (bandwidth.depth / 64.0f));
     }
 }
 
@@ -184,7 +187,7 @@ void Controller::setmodwheel(int value)
     modwheel.data = value;
     if (!modwheel.exponential)
     {
-        float tmp = powf(25.0f, powf(modwheel.depth / 127.0f, 1.5f) * 2.0f) / 25.0f;
+        float tmp = power<25>(powf(modwheel.depth / 127.0f, 1.5f) * 2.0f) / 25.0f;
         if (value < 64 && modwheel.depth >= 64)
             tmp = 1.0f;
         modwheel.relmod = (value / 64.0f - 1.0f) * tmp + 1.0f;
@@ -192,7 +195,7 @@ void Controller::setmodwheel(int value)
             modwheel.relmod = 0.0f;
     }
     else
-        modwheel.relmod = powf(25.0f, (value - 64.0f) / 64.0f * (modwheel.depth / 80.0f));
+        modwheel.relmod = power<25>((value - 64.0f) / 64.0f * (modwheel.depth / 80.0f));
 }
 
 
@@ -234,29 +237,30 @@ void Controller::setportamento(int value)
 }
 
 
-int Controller::initportamento(float oldfreq, float newfreq, bool in_progress)
+// returns true if portamento's preconditions are met
+bool Controller::initportamento(float oldfreq, float newfreq, bool in_progress)
 {
     portamento.x = 0.0f;
 
     if (in_progress)
     {   // Legato in progress
         if (!portamento.portamento)
-            return 0;
+            return false;
     }
     else
     {   // No legato, do the original if...return
         if (portamento.used != 0 || !portamento.portamento)
-            return 0;
+            return false;
     }
 
-    float portamentotime = powf(100.0f, portamento.time / 127.0f) / 50.0f; // portamento time in seconds
+    float portamentotime = power<100>(portamento.time / 127.0f) / 50.0f; // portamento time in seconds
 
-    if(portamento.proportional)
+    if (portamento.proportional)
     {
         //If there is a min(float,float) and a max(float,float) then they
         //could be used here
         //Linear functors could also make this nicer
-        if(oldfreq > newfreq) //2 is the center of propRate
+        if (oldfreq > newfreq) //2 is the center of propRate
             portamentotime *=
                 powf(oldfreq / newfreq
                      / (portamento.propRate / 127.0f * 3 + .05),
@@ -271,36 +275,36 @@ int Controller::initportamento(float oldfreq, float newfreq, bool in_progress)
     if (portamento.updowntimestretch >= 64 && newfreq < oldfreq)
     {
         if (portamento.updowntimestretch == 127)
-            return 0;
-        portamentotime *= powf(0.1f, (portamento.updowntimestretch - 64) / 63.0f);
+            return false;
+        portamentotime *= powFrac<10>((portamento.updowntimestretch - 64) / 63.0f);
     }
     if (portamento.updowntimestretch < 64 && newfreq > oldfreq)
     {
         if (portamento.updowntimestretch == 0)
-            return 0;
-        portamentotime *= powf(0.1f, (64.0f - portamento.updowntimestretch) / 64.0f);
+            return false;
+        portamentotime *= powFrac<10>((64.0f - portamento.updowntimestretch) / 64.0f);
     }
 
-    portamento.dx = synth->sent_all_buffersize_f / (portamentotime * synth->samplerate_f);
+    portamento.dx = synth->fixed_sample_step_f / portamentotime;
     portamento.origfreqrap = oldfreq / newfreq;
 
     float tmprap = (portamento.origfreqrap > 1.0f)
                           ? portamento.origfreqrap
                           : 1.0 / portamento.origfreqrap ;
 
-    float thresholdrap = powf(2.0f, portamento.pitchthresh / 12.0f);
+    float thresholdrap = power<2>(portamento.pitchthresh / 12.0f);
     if (portamento.pitchthreshtype == 0 && (tmprap - 0.00001f) > thresholdrap)
-        return 0;
+        return false;
     if (portamento.pitchthreshtype == 1 && (tmprap + 0.00001f) < thresholdrap)
-        return 0;
+        return false;
 
     portamento.used = 1;
     portamento.freqrap = portamento.origfreqrap;
-    return 1;
+    return true;
 }
 
 
-void Controller::updateportamento(void)
+void Controller::updateportamento()
 {
     if (portamento.used)
     {
@@ -318,83 +322,88 @@ void Controller::updateportamento(void)
 void Controller::setresonancecenter(int value)
 {
     resonancecenter.data = value;
-    resonancecenter.relcenter = powf(3.0f, (value - 64.0f) / 64.0f * (resonancecenter.depth / 64.0f));
+    resonancecenter.relcenter = power<3>((value - 64.0f) / 64.0f * (resonancecenter.depth / 64.0f));
 }
 
 
+namespace {
+    static const float LN_BASE1_5 = log(1.5);
+    inline float power1_5(float exponent) { return expf(LN_BASE1_5 * exponent); } // 1.5^exponent
+}
+
 void Controller::setresonancebw(int value)
 {
     resonancebandwidth.data = value;
-    resonancebandwidth.relbw = powf(1.5f, (value - 64.0f) / 64.0f * (resonancebandwidth.depth / 127.0f));
+    resonancebandwidth.relbw = power1_5((value - 64.0f) / 64.0f * (resonancebandwidth.depth / 127.0f));
 }
 
 
-void Controller::add2XML(XMLwrapper *xml)
+void Controller::add2XML(XMLwrapper& xml)
 {
-    xml->addpar("pitchwheel_bendrange", pitchwheel.bendrange);
+    xml.addpar("pitchwheel_bendrange", pitchwheel.bendrange);
 
-    xml->addparbool("expression_receive",expression.receive);
-    xml->addpar("panning_depth", (char)panning.depth);
-    xml->addpar("filter_cutoff_depth",filtercutoff.depth);
-    xml->addpar("filter_q_depth",filterq.depth);
-    xml->addpar("bandwidth_depth",bandwidth.depth);
-    xml->addpar("mod_wheel_depth",modwheel.depth);
-    xml->addparbool("mod_wheel_exponential",modwheel.exponential);
-    xml->addparbool("fm_amp_receive",fmamp.receive);
-    xml->addparbool("volume_receive",volume.receive);
-    xml->addpar("volume_range",volume.data);
-    xml->addparbool("sustain_receive",sustain.receive);
+    xml.addparbool("expression_receive",expression.receive);
+    xml.addpar("panning_depth", (char)panning.depth);
+    xml.addpar("filter_cutoff_depth",filtercutoff.depth);
+    xml.addpar("filter_q_depth",filterq.depth);
+    xml.addpar("bandwidth_depth",bandwidth.depth);
+    xml.addpar("mod_wheel_depth",modwheel.depth);
+    xml.addparbool("mod_wheel_exponential",modwheel.exponential);
+    xml.addparbool("fm_amp_receive",fmamp.receive);
+    xml.addparbool("volume_receive",volume.receive);
+    xml.addpar("volume_range",volume.data);
+    xml.addparbool("sustain_receive",sustain.receive);
 
-    xml->addparbool("portamento_receive",portamento.receive);
-    xml->addpar("portamento_time",portamento.time);
-    xml->addpar("portamento_pitchthresh",portamento.pitchthresh);
-    xml->addpar("portamento_pitchthreshtype",portamento.pitchthreshtype);
-    xml->addpar("portamento_portamento",portamento.portamento);
-    xml->addpar("portamento_updowntimestretch",portamento.updowntimestretch);
-    xml->addpar("portamento_proportional", portamento.proportional);
-    xml->addpar("portamento_proprate", portamento.propRate);
-    xml->addpar("portamento_propdepth", portamento.propDepth);
+    xml.addparbool("portamento_receive",portamento.receive);
+    xml.addpar("portamento_time",portamento.time);
+    xml.addpar("portamento_pitchthresh",portamento.pitchthresh);
+    xml.addpar("portamento_pitchthreshtype",portamento.pitchthreshtype);
+    xml.addpar("portamento_portamento",portamento.portamento);
+    xml.addpar("portamento_updowntimestretch",portamento.updowntimestretch);
+    xml.addpar("portamento_proportional", portamento.proportional);
+    xml.addpar("portamento_proprate", portamento.propRate);
+    xml.addpar("portamento_propdepth", portamento.propDepth);
 
-    xml->addpar("resonance_center_depth",resonancecenter.depth);
-    xml->addpar("resonance_bandwidth_depth",resonancebandwidth.depth);
+    xml.addpar("resonance_center_depth",resonancecenter.depth);
+    xml.addpar("resonance_bandwidth_depth",resonancebandwidth.depth);
 }
 
 
-void Controller::getfromXML(XMLwrapper *xml)
+void Controller::getfromXML(XMLwrapper& xml)
 {
-    pitchwheel.bendrange=xml->getpar("pitchwheel_bendrange",pitchwheel.bendrange,-6400,6400);
+    pitchwheel.bendrange= xml.getpar("pitchwheel_bendrange",pitchwheel.bendrange,-6400,6400);
 
-    expression.receive=xml->getparbool("expression_receive",expression.receive);
-    panning.depth = xml->getpar127("panning_depth", panning.depth);
-    filtercutoff.depth=xml->getpar127("filter_cutoff_depth",filtercutoff.depth);
-    filterq.depth=xml->getpar127("filter_q_depth",filterq.depth);
-    bandwidth.depth=xml->getpar127("bandwidth_depth",bandwidth.depth);
-    modwheel.depth=xml->getpar127("mod_wheel_depth",modwheel.depth);
-    modwheel.exponential=xml->getparbool("mod_wheel_exponential",modwheel.exponential);
-    fmamp.receive=xml->getparbool("fm_amp_receive",fmamp.receive);
-    volume.receive=xml->getparbool("volume_receive",volume.receive);
-    setvolume(xml->getpar127("volume_range",volume.data));
+    expression.receive  = xml.getparbool("expression_receive",expression.receive);
+    panning.depth       = xml.getpar127("panning_depth", panning.depth);
+    filtercutoff.depth  = xml.getpar127("filter_cutoff_depth",filtercutoff.depth);
+    filterq.depth       = xml.getpar127("filter_q_depth",filterq.depth);
+    bandwidth.depth     = xml.getpar127("bandwidth_depth",bandwidth.depth);
+    modwheel.depth      = xml.getpar127("mod_wheel_depth",modwheel.depth);
+    modwheel.exponential= xml.getparbool("mod_wheel_exponential",modwheel.exponential);
+    fmamp.receive       = xml.getparbool("fm_amp_receive",fmamp.receive);
+    volume.receive      = xml.getparbool("volume_receive",volume.receive);
+    setvolume(xml.getpar127("volume_range",volume.data));
 
-    sustain.receive=xml->getparbool("sustain_receive",sustain.receive);
+    sustain.receive     = xml.getparbool("sustain_receive",sustain.receive);
 
-    portamento.receive=xml->getparbool("portamento_receive",portamento.receive);
-    portamento.time=xml->getpar127("portamento_time",portamento.time);
-    portamento.pitchthresh=xml->getpar127("portamento_pitchthresh",portamento.pitchthresh);
-    portamento.pitchthreshtype=xml->getpar127("portamento_pitchthreshtype",portamento.pitchthreshtype);
-    portamento.portamento=xml->getpar127("portamento_portamento",portamento.portamento);
-    portamento.updowntimestretch=xml->getpar127("portamento_updowntimestretch",portamento.updowntimestretch);
-    portamento.proportional = xml->getpar127("portamento_proportional",portamento.proportional);
-    portamento.propRate = xml->getpar127("portamento_proprate",portamento.propRate);
-    portamento.propDepth = xml->getpar127("portamento_propdepth",portamento.propDepth);
+    portamento.receive          = xml.getparbool("portamento_receive",portamento.receive);
+    portamento.time             = xml.getpar127("portamento_time",portamento.time);
+    portamento.pitchthresh      = xml.getpar127("portamento_pitchthresh",portamento.pitchthresh);
+    portamento.pitchthreshtype  = xml.getpar127("portamento_pitchthreshtype",portamento.pitchthreshtype);
+    portamento.portamento       = xml.getpar127("portamento_portamento",portamento.portamento);
+    portamento.updowntimestretch= xml.getpar127("portamento_updowntimestretch",portamento.updowntimestretch);
+    portamento.proportional     = xml.getpar127("portamento_proportional",portamento.proportional);
+    portamento.propRate         = xml.getpar127("portamento_proprate",portamento.propRate);
+    portamento.propDepth        = xml.getpar127("portamento_propdepth",portamento.propDepth);
 
-    resonancecenter.depth=xml->getpar127("resonance_center_depth",resonancecenter.depth);
-    resonancebandwidth.depth=xml->getpar127("resonance_bandwidth_depth",resonancebandwidth.depth);
+    resonancecenter.depth    = xml.getpar127("resonance_center_depth",resonancecenter.depth);
+    resonancebandwidth.depth = xml.getpar127("resonance_bandwidth_depth",resonancebandwidth.depth);
 }
 
 
 float Controller::getLimits(CommandBlock *getData)
 {
-    float value = getData->data.value.F;
+    float value = getData->data.value;
     unsigned char type = getData->data.type;
     int request = type & TOPLEVEL::type::Default;
     int control = getData->data.control;
@@ -512,9 +521,9 @@ float Controller::getLimits(CommandBlock *getData)
     switch (request)
     {
         case TOPLEVEL::type::Adjust:
-            if(value < min)
+            if (value < min)
                 value = min;
-            else if(value > max)
+            else if (value > max)
                 value = max;
         break;
         case TOPLEVEL::type::Minimum:
