@@ -30,9 +30,9 @@
 #include "Misc/SynthEngine.h"
 #include "Params/OscilParameters.h" // **** RHL ****
 
-OscilParameters::OscilParameters(fft::Calc const& fft, SynthEngine *_synth) :
-    ParamBase(_synth),
-    basefuncSpectrum(fft.spectrumSize())
+OscilParameters::OscilParameters(fft::Calc const& fft, SynthEngine& _synth)
+    : ParamBase{_synth}
+    , basefuncSpectrum{fft.spectrumSize()}
 {
     defaults();
 }
@@ -90,56 +90,56 @@ void OscilParameters::defaults()
     Padaptiveharmonicspar = 50;
 }
 
-void OscilParameters::add2XML(XMLwrapper *xml)
+void OscilParameters::add2XML(XMLwrapper& xml)
 {
-    xml->addpar("harmonic_mag_type", Phmagtype);
+    xml.addpar("harmonic_mag_type", Phmagtype);
 
-    xml->addpar("base_function", Pcurrentbasefunc);
-    xml->addpar("base_function_par", Pbasefuncpar);
-    xml->addpar("base_function_modulation", Pbasefuncmodulation);
-    xml->addpar("base_function_modulation_par1", Pbasefuncmodulationpar1);
-    xml->addpar("base_function_modulation_par2", Pbasefuncmodulationpar2);
-    xml->addpar("base_function_modulation_par3", Pbasefuncmodulationpar3);
+    xml.addpar("base_function", Pcurrentbasefunc);
+    xml.addpar("base_function_par", Pbasefuncpar);
+    xml.addpar("base_function_modulation", Pbasefuncmodulation);
+    xml.addpar("base_function_modulation_par1", Pbasefuncmodulationpar1);
+    xml.addpar("base_function_modulation_par2", Pbasefuncmodulationpar2);
+    xml.addpar("base_function_modulation_par3", Pbasefuncmodulationpar3);
 
-    xml->addpar("modulation", Pmodulation);
-    xml->addpar("modulation_par1", Pmodulationpar1);
-    xml->addpar("modulation_par2", Pmodulationpar2);
-    xml->addpar("modulation_par3", Pmodulationpar3);
+    xml.addpar("modulation", Pmodulation);
+    xml.addpar("modulation_par1", Pmodulationpar1);
+    xml.addpar("modulation_par2", Pmodulationpar2);
+    xml.addpar("modulation_par3", Pmodulationpar3);
 
-    xml->addpar("wave_shaping", Pwaveshaping);
-    xml->addpar("wave_shaping_function", Pwaveshapingfunction);
+    xml.addpar("wave_shaping", Pwaveshaping);
+    xml.addpar("wave_shaping_function", Pwaveshapingfunction);
 
-    xml->addpar("filter_type", Pfiltertype);
-    xml->addpar("filter_par1", Pfilterpar1);
-    xml->addpar("filter_par2", Pfilterpar2);
-    xml->addpar("filter_before_wave_shaping", Pfilterbeforews);
+    xml.addpar("filter_type", Pfiltertype);
+    xml.addpar("filter_par1", Pfilterpar1);
+    xml.addpar("filter_par2", Pfilterpar2);
+    xml.addpar("filter_before_wave_shaping", Pfilterbeforews);
 
-    xml->addpar("spectrum_adjust_type", Psatype);
-    xml->addpar("spectrum_adjust_par", Psapar);
+    xml.addpar("spectrum_adjust_type", Psatype);
+    xml.addpar("spectrum_adjust_par", Psapar);
 
-    xml->addpar("rand", Prand);
-    xml->addpar("amp_rand_type", Pamprandtype);
-    xml->addpar("amp_rand_power", Pamprandpower);
+    xml.addpar("rand", Prand);
+    xml.addpar("amp_rand_type", Pamprandtype);
+    xml.addpar("amp_rand_power", Pamprandpower);
 
-    xml->addpar("harmonic_shift", Pharmonicshift);
-    xml->addparbool("harmonic_shift_first", Pharmonicshiftfirst);
+    xml.addpar("harmonic_shift", Pharmonicshift);
+    xml.addparbool("harmonic_shift_first", Pharmonicshiftfirst);
 
-    xml->addpar("adaptive_harmonics", Padaptiveharmonics);
-    xml->addpar("adaptive_harmonics_base_frequency", Padaptiveharmonicsbasefreq);
-    xml->addpar("adaptive_harmonics_power", Padaptiveharmonicspower);
-    xml->addpar("adaptive_harmonics_par", Padaptiveharmonicspar);
+    xml.addpar("adaptive_harmonics", Padaptiveharmonics);
+    xml.addpar("adaptive_harmonics_base_frequency", Padaptiveharmonicsbasefreq);
+    xml.addpar("adaptive_harmonics_power", Padaptiveharmonicspower);
+    xml.addpar("adaptive_harmonics_par", Padaptiveharmonicspar);
 
-    xml->beginbranch("HARMONICS");
+    xml.beginbranch("HARMONICS");
         for (int n = 0; n < MAX_AD_HARMONICS; ++n)
         {
             if (Phmag[n] == 64 && Phphase[n] == 64)
                 continue;
-            xml->beginbranch("HARMONIC", n + 1);
-                xml->addpar("mag", Phmag[n]);
-                xml->addpar("phase", Phphase[n]);
-            xml->endbranch();
+            xml.beginbranch("HARMONIC", n + 1);
+                xml.addpar("mag", Phmag[n]);
+                xml.addpar("phase", Phphase[n]);
+            xml.endbranch();
         }
-    xml->endbranch();
+    xml.endbranch();
 
     if (Pcurrentbasefunc == OSCILLATOR::wave::user)
     {
@@ -154,94 +154,94 @@ void OscilParameters::add2XML(XMLwrapper *xml)
         if (max < 0.00000001)
             max = 1.0;
 
-        xml->beginbranch("BASE_FUNCTION");
+        xml.beginbranch("BASE_FUNCTION");
             for (size_t i = 1; i < basefuncSpectrum.size(); ++i)
             {
                 float xc = basefuncSpectrum.c(i) / max;
                 float xs = basefuncSpectrum.s(i) / max;
                 if (fabsf(xs) > 0.00001 && fabsf(xs) > 0.00001)
                 {
-                    xml->beginbranch("BF_HARMONIC", i);
-                        xml->addparreal("cos", xc);
-                        xml->addparreal("sin", xs);
-                    xml->endbranch();
+                    xml.beginbranch("BF_HARMONIC", i);
+                        xml.addparreal("cos", xc);
+                        xml.addparreal("sin", xs);
+                    xml.endbranch();
                 }
             }
-        xml->endbranch();
+        xml.endbranch();
     }
 }
 
 
-void OscilParameters::getfromXML(XMLwrapper *xml)
+void OscilParameters::getfromXML(XMLwrapper& xml)
 {
 
-    Phmagtype = xml->getpar127("harmonic_mag_type", Phmagtype);
+    Phmagtype = xml.getpar127("harmonic_mag_type", Phmagtype);
 
-    Pcurrentbasefunc = xml->getpar127("base_function", Pcurrentbasefunc);
-    Pbasefuncpar = xml->getpar127("base_function_par", Pbasefuncpar);
+    Pcurrentbasefunc = xml.getpar127("base_function", Pcurrentbasefunc);
+    Pbasefuncpar = xml.getpar127("base_function_par", Pbasefuncpar);
 
-    Pbasefuncmodulation = xml->getpar127("base_function_modulation", Pbasefuncmodulation);
-    Pbasefuncmodulationpar1 = xml->getpar127("base_function_modulation_par1", Pbasefuncmodulationpar1);
-    Pbasefuncmodulationpar2 = xml->getpar127("base_function_modulation_par2", Pbasefuncmodulationpar2);
-    Pbasefuncmodulationpar3 = xml->getpar127("base_function_modulation_par3", Pbasefuncmodulationpar3);
+    Pbasefuncmodulation = xml.getpar127("base_function_modulation", Pbasefuncmodulation);
+    Pbasefuncmodulationpar1 = xml.getpar127("base_function_modulation_par1", Pbasefuncmodulationpar1);
+    Pbasefuncmodulationpar2 = xml.getpar127("base_function_modulation_par2", Pbasefuncmodulationpar2);
+    Pbasefuncmodulationpar3 = xml.getpar127("base_function_modulation_par3", Pbasefuncmodulationpar3);
 
-    Pmodulation = xml->getpar127("modulation", Pmodulation);
-    Pmodulationpar1 = xml->getpar127("modulation_par1", Pmodulationpar1);
-    Pmodulationpar2 = xml->getpar127("modulation_par2", Pmodulationpar2);
-    Pmodulationpar3 = xml->getpar127("modulation_par3", Pmodulationpar3);
+    Pmodulation = xml.getpar127("modulation", Pmodulation);
+    Pmodulationpar1 = xml.getpar127("modulation_par1", Pmodulationpar1);
+    Pmodulationpar2 = xml.getpar127("modulation_par2", Pmodulationpar2);
+    Pmodulationpar3 = xml.getpar127("modulation_par3", Pmodulationpar3);
 
-    Pwaveshaping = xml->getpar127("wave_shaping", Pwaveshaping);
-    Pwaveshapingfunction = xml->getpar127("wave_shaping_function", Pwaveshapingfunction);
+    Pwaveshaping = xml.getpar127("wave_shaping", Pwaveshaping);
+    Pwaveshapingfunction = xml.getpar127("wave_shaping_function", Pwaveshapingfunction);
 
-    Pfiltertype = xml->getpar127("filter_type", Pfiltertype);
-    Pfilterpar1 = xml->getpar127("filter_par1", Pfilterpar1);
-    Pfilterpar2 = xml->getpar127("filter_par2", Pfilterpar2);
-    Pfilterbeforews = xml->getpar127("filter_before_wave_shaping", Pfilterbeforews);
+    Pfiltertype = xml.getpar127("filter_type", Pfiltertype);
+    Pfilterpar1 = xml.getpar127("filter_par1", Pfilterpar1);
+    Pfilterpar2 = xml.getpar127("filter_par2", Pfilterpar2);
+    Pfilterbeforews = xml.getpar127("filter_before_wave_shaping", Pfilterbeforews);
 
-    Psatype = xml->getpar127("spectrum_adjust_type", Psatype);
-    Psapar = xml->getpar127("spectrum_adjust_par", Psapar);
+    Psatype = xml.getpar127("spectrum_adjust_type", Psatype);
+    Psapar = xml.getpar127("spectrum_adjust_par", Psapar);
 
-    Prand = xml->getpar127("rand", Prand);
-    Pamprandtype = xml->getpar127("amp_rand_type", Pamprandtype);
-    Pamprandpower = xml->getpar127("amp_rand_power", Pamprandpower);
+    Prand = xml.getpar127("rand", Prand);
+    Pamprandtype = xml.getpar127("amp_rand_type", Pamprandtype);
+    Pamprandpower = xml.getpar127("amp_rand_power", Pamprandpower);
 
-    Pharmonicshift = xml->getpar("harmonic_shift", Pharmonicshift, -64, 64);
-    Pharmonicshiftfirst = xml->getparbool("harmonic_shift_first", Pharmonicshiftfirst);
+    Pharmonicshift = xml.getpar("harmonic_shift", Pharmonicshift, -64, 64);
+    Pharmonicshiftfirst = xml.getparbool("harmonic_shift_first", Pharmonicshiftfirst);
 
-    Padaptiveharmonics = xml->getpar("adaptive_harmonics", Padaptiveharmonics, 0, 127);
-    Padaptiveharmonicsbasefreq = xml->getpar("adaptive_harmonics_base_frequency", Padaptiveharmonicsbasefreq,0,255);
-    Padaptiveharmonicspower = xml->getpar("adaptive_harmonics_power", Padaptiveharmonicspower, 0, 200);
-    Padaptiveharmonicspar = xml->getpar("adaptive_harmonics_par", Padaptiveharmonicspar, 0, 100);
+    Padaptiveharmonics = xml.getpar("adaptive_harmonics", Padaptiveharmonics, 0, 127);
+    Padaptiveharmonicsbasefreq = xml.getpar("adaptive_harmonics_base_frequency", Padaptiveharmonicsbasefreq,0,255);
+    Padaptiveharmonicspower = xml.getpar("adaptive_harmonics_power", Padaptiveharmonicspower, 0, 200);
+    Padaptiveharmonicspar = xml.getpar("adaptive_harmonics_par", Padaptiveharmonicspar, 0, 100);
 
-    if (xml->enterbranch("HARMONICS"))
+    if (xml.enterbranch("HARMONICS"))
     {
         Phmag[0] = 64;
         Phphase[0] = 64;
         for (int n = 0; n < MAX_AD_HARMONICS; ++n)
         {
-            if (xml->enterbranch("HARMONIC",n + 1) == 0)
+            if (xml.enterbranch("HARMONIC",n + 1) == 0)
                 continue;
-            Phmag[n] = xml->getpar127("mag", 64);
-            Phphase[n] = xml->getpar127("phase", 64);
+            Phmag[n] = xml.getpar127("mag", 64);
+            Phphase[n] = xml.getpar127("phase", 64);
 
-            xml->exitbranch();
+            xml.exitbranch();
         }
-        xml->exitbranch();
+        xml.exitbranch();
     }
 
-    if (xml->enterbranch("BASE_FUNCTION"))
+    if (xml.enterbranch("BASE_FUNCTION"))
     {
         for (size_t i = 1; i < basefuncSpectrum.size(); ++i)
         {
-            if (xml->enterbranch("BF_HARMONIC", i))
+            if (xml.enterbranch("BF_HARMONIC", i))
             {
-                basefuncSpectrum.c(i) = xml->getparreal("cos", 0.0);
-                basefuncSpectrum.s(i) = xml->getparreal("sin", 0.0);
+                basefuncSpectrum.c(i) = xml.getparreal("cos", 0.0);
+                basefuncSpectrum.s(i) = xml.getparreal("sin", 0.0);
 
-                xml->exitbranch();
+                xml.exitbranch();
             }
         }
-        xml->exitbranch();
+        xml.exitbranch();
 
         float max = 0.0;
 
@@ -275,14 +275,14 @@ float OscilParameters::getLimits(CommandBlock *getData)
     int control = getData->data.control;
     int insert = getData->data.insert;
 
-    unsigned char type = 0;
+    uchar type = 0;
 
     // oscillator defaults
     int min = 0;
     int max = 127;
     float def = 0;
     type |= TOPLEVEL::type::Integer;
-    unsigned char learnable = TOPLEVEL::type::Learnable;
+    uchar learnable = TOPLEVEL::type::Learnable;
     type |= learnable;
 
     if (insert == TOPLEVEL::insert::harmonicAmplitude || insert == TOPLEVEL::insert::harmonicPhase)
